summaryrefslogtreecommitdiffstats
path: root/examples/glob/src/main.rs
diff options
context:
space:
mode:
Diffstat (limited to 'examples/glob/src/main.rs')
-rw-r--r--examples/glob/src/main.rs14
1 files changed, 7 insertions, 7 deletions
diff --git a/examples/glob/src/main.rs b/examples/glob/src/main.rs
index b3183ef..c85f86e 100644
--- a/examples/glob/src/main.rs
+++ b/examples/glob/src/main.rs
@@ -1,5 +1,5 @@
use std::path::Path;
-use std::collections::HashMap;
+use std::collections::LinkedHashMap;
use config::*;
use glob::glob;
@@ -14,9 +14,9 @@ fn main() {
.merge(File::from(Path::new("conf/05-some.yml"))).unwrap()
.merge(File::from(Path::new("conf/99-extra.json"))).unwrap();
// Print out our settings (as a HashMap)
println!("\n{:?} \n\n-----------",
- settings.try_into::<HashMap<String, String>>().unwrap());
+ settings.try_into::<LinkedHashMap<String, String>>().unwrap());
// Option 2
// --------
@@ -28,9 +28,9 @@ fn main() {
File::from(Path::new("conf/99-extra.json"))])
.unwrap();
// Print out our settings (as a HashMap)
println!("\n{:?} \n\n-----------",
- settings.try_into::<HashMap<String, String>>().unwrap());
+ settings.try_into::<LinkedHashMap<String, String>>().unwrap());
// Option 3
// --------
@@ -43,7 +43,7 @@ fn main() {
.collect::<Vec<_>>())
.unwrap();
// Print out our settings (as a HashMap)
println!("\n{:?} \n\n-----------",
- settings.try_into::<HashMap<String, String>>().unwrap());
+ settings.try_into::<LinkedHashMap<String, String>>().unwrap());
}
@@ -14,9 +14,9 @@ fn main() {
.merge(File::from(Path::new("conf/05-some.yml"))).unwrap()
.merge(File::from(Path::new("conf/99-extra.json"))).unwrap();
- // Print out our settings (as a HashMap)
+ // Print out our settings (as a LinkedHashMap)
println!("\n{:?} \n\n-----------",
@@ -28,9 +28,9 @@ fn main() {
File::from(Path::new("conf/99-extra.json"))])
.unwrap();
- // Print out our settings (as a HashMap)
+ // Print out our settings (as a LinkedHashMap)
println!("\n{:?} \n\n-----------",
@@ -43,7 +43,7 @@ fn main() {
.collect::<Vec<_>>())
.unwrap();
- // Print out our settings (as a HashMap)
+ // Print out our settings (as a LinkedHashMap)
println!("\n{:?} \n\n-----------",